@@ -321,6 +321,8 @@ class RatingWorkflowDefacing(BaseWorkflowVisualQC, ABC):
 
         self.init_layout()
 
+        self.__module_type__ = 'defacing'
+
 
     def preprocess(self):
         """Preprocessing if necessary."""
@@ -689,11 +691,9 @@ def make_workflow_from_user_options():
 def cli_run():
     """Main entry point."""
 
-    from visualqc import __version__
-    print('\nvisualqc version {} for defacing'.format(__version__))
-    from datetime import datetime
-    init_time = datetime.now()
-    print('\tTime stamp : {}\n'.format(init_time.strftime('%Y-%m-%d %H:%M:%S')))
+    print('\nDefacing module')
+    from visualqc.utils import run_common_utils_before_starting
+    run_common_utils_before_starting()
 
     wf = make_workflow_from_user_options()
 
