@@ -336,6 +336,8 @@ class RatingWorkflowT1(BaseWorkflowVisualQC, ABC):
         self.init_layout(views, num_rows_per_view, num_slices_per_view)
         self.init_getters()
 
+        self.__module_type__ = 't1_mri'
+
 
     def preprocess(self):
         """
@@ -863,11 +865,9 @@ def make_workflow_from_user_options():
 def cli_run():
     """Main entry point."""
 
-    from visualqc import __version__
-    print('\nvisualqc version {} for anatomical MRI'.format(__version__))
-    from datetime import datetime
-    init_time = datetime.now()
-    print('\tTime stamp : {}\n'.format(init_time.strftime('%Y-%m-%d %H:%M:%S')))
+    print('\nAnatomical MRI module')
+    from visualqc.utils import run_common_utils_before_starting
+    run_common_utils_before_starting()
 
     wf = make_workflow_from_user_options()
 
