@@ -859,6 +859,13 @@ def get_freesurfer_mri_path(in_dir, subject_id, req_file):
     return realpath(pjoin(in_dir, subject_id, 'mri', req_file))
 
 
+def run_common_utils_before_starting():
+    """Run simple utils common to all modules before starting VisualQC"""
+
+    print_time_stamp()
+    print_platform_version_info()
+
+
 def check_time(time_interval, var_name='time interval'):
     """"""
 
@@ -1070,6 +1077,14 @@ def check_inputs_defacing(in_dir, defaced_name, mri_name, render_name, id_list_i
            defaced_name, mri_name, render_name
 
 
+def print_time_stamp():
+    """Prints a time stamp for debugging purposes"""
+
+    from datetime import datetime
+    init_time = datetime.now()
+    print('Time stamp : {}\n'.format(init_time.strftime('%Y-%m-%d %H:%M:%S')))
+
+
 def compute_cell_extents_grid(bounding_rect=(0.03, 0.03, 0.97, 0.97),
                               num_rows=2, num_cols=6,
                               axis_pad=0.01):
@@ -1096,3 +1111,16 @@ def compute_cell_extents_grid(bounding_rect=(0.03, 0.03, 0.97, 0.97),
                             cell_width, cell_height))
 
     return extents
+
+
+def print_platform_version_info():
+    """Small utility to print all relevant version info for debugging purposes"""
+
+    import scipy
+    import platform
+    import matplotlib
+    from visualqc import __version__
+    print('version info: visualqc {}'.format(__version__))
+    print('numpy {} / scipy {} / matplotlib {}\npython {}'.format(
+        np.__version__, scipy.__version__, matplotlib.__version__, sys.version))
+    print('platform {}\n{}\n\n'.format(platform.platform(), platform.version()))
